@@ -63,10 +63,6 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #define ERROR_COULD_NOT_CREATE_THREAD 100
 
-#ifndef MAX_PATH
-#define MAX_PATH 256
-#endif
-
 #ifndef min
 #define min(x, y) ((x < y) ? (x) : (y))
 #endif
@@ -491,9 +487,9 @@ static bool is_directory(const char_t* path)
 static int scan_dir(const char_t* dir, SCAN_OPTIONS* scan_opts)
 {
   int result = ERROR_SUCCESS;
-  char_t path[MAX_PATH];
+  char_t path[YR_MAX_PATH];
 
-  _sntprintf(path, MAX_PATH, _T("%s\\*"), dir);
+  _sntprintf(path, YR_MAX_PATH, _T("%s\\*"), dir);
 
   WIN32_FIND_DATA FindFileData;
   HANDLE hFind = FindFirstFile(path, &FindFileData);
@@ -502,7 +498,7 @@ static int scan_dir(const char_t* dir, SCAN_OPTIONS* scan_opts)
   {
     do
     {
-      _sntprintf(path, MAX_PATH, _T("%s\\%s"), dir, FindFileData.cFileName);
+      _sntprintf(path, YR_MAX_PATH, _T("%s\\%s"), dir, FindFileData.cFileName);
 
       if (!(FindFileData.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY))
       {
@@ -671,12 +667,14 @@ static int scan_dir(const char* dir, SCAN_OPTIONS* scan_opts)
   {
     struct dirent* de = readdir(dp);
 
+    char* full_path = calloc(YR_MAX_PATH, sizeof(char));
+    const size_t full_path_size = YR_MAX_PATH * sizeof(char);
+
     while (de && result != ERROR_SCAN_TIMEOUT)
     {
-      char full_path[MAX_PATH];
       struct stat st;
 
-      snprintf(full_path, sizeof(full_path), "%s/%s", dir, de->d_name);
+      snprintf(full_path, full_path_size, "%s/%s", dir, de->d_name);
 
       int err = lstat(full_path, &st);
 
@@ -735,6 +733,7 @@ static int scan_dir(const char* dir, SCAN_OPTIONS* scan_opts)
       de = readdir(dp);
     }
 
+    free(full_path);
     closedir(dp);
   }
 
@@ -811,7 +810,7 @@ static char cescapes[] = {
     0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0,   0,   0, 0,
 };
 
-static void print_escaped(const uint8_t* data, size_t length)
+static void print_escaped_data(const uint8_t* data, size_t length)
 {
   for (size_t i = 0; i < length; i++)
   {
@@ -836,6 +835,20 @@ static void print_escaped(const uint8_t* data, size_t length)
   }
 }
 
+void print_escaped_file_path(const char_t* str) {
+    for (size_t i = 0; str[i] != '\0'; ++i) {
+        if (str[i] == _T('\n')) {
+            _tprintf(_T("\\n"));
+        } else if (str[i] == _T('\r')) {
+            _tprintf(_T("\\r"));
+        }
+        else {
+            _tprintf(_T("%c"), str[i]);
+        }
+    }
+    _tprintf(_T("\n"));
+}
+
 static void print_hex_string(const uint8_t* data, int length)
 {
   for (int i = 0; i < min(64, length); i++)
@@ -1099,7 +1112,7 @@ static int handle_message(
         else
         {
           _tprintf(_T("%" PF_S "=\""), meta->identifier);
-          print_escaped((uint8_t*) (meta->string), strlen(meta->string));
+          print_escaped_data((uint8_t*) (meta->string), strlen(meta->string));
           _tprintf(_T("\""));
         }
       }
@@ -1107,7 +1120,7 @@ static int handle_message(
       _tprintf(_T("] "));
     }
 
-    _tprintf(_T("%s\n"), ((CALLBACK_ARGS*) data)->file_path);
+    print_escaped_file_path(((CALLBACK_ARGS*) data)->file_path);
 
     // Show matched strings.
 
