@@ -325,17 +325,26 @@ YR_API int yr_rules_scan_proc(
 
 int yr_rules_from_arena(YR_ARENA* arena, YR_RULES** rules)
 {
-  YR_RULES* new_rules = (YR_RULES*) yr_malloc(sizeof(YR_RULES));
-
-  if (new_rules == NULL)
-    return ERROR_INSUFFICIENT_MEMORY;
-
   YR_SUMMARY* summary = (YR_SUMMARY*) yr_arena_get_ptr(
       arena, YR_SUMMARY_SECTION, 0);
 
   if (summary == NULL)
     return ERROR_CORRUPT_FILE;
 
+  YR_RULES* new_rules = (YR_RULES*) yr_malloc(sizeof(YR_RULES));
+
+  if (new_rules == NULL)
+    return ERROR_INSUFFICIENT_MEMORY;
+
+  new_rules->no_required_strings = (YR_BITMASK*) yr_calloc(
+      sizeof(YR_BITMASK), YR_BITMASK_SIZE(summary->num_rules));
+
+  if (new_rules->no_required_strings == NULL)
+  {
+    yr_free(new_rules);
+    return ERROR_INSUFFICIENT_MEMORY;
+  }
+
   // Now YR_RULES relies on this arena, let's increment the arena's
   // reference count so that if the original owner of the arena calls
   // yr_arena_destroy the arena is not destroyed.
@@ -364,6 +373,15 @@ int yr_rules_from_arena(YR_ARENA* arena, YR_RULES** rules)
 
   new_rules->code_start = yr_arena_get_ptr(arena, YR_CODE_SECTION, 0);
 
+  // If a rule has no required_strings, this means that the condition might
+  // evaluate to true without any matching strings, and we therefore have to
+  // mark it as "to be evaluated" from the beginning.
+  for (int i = 0; i < new_rules->num_rules; i++)
+  {
+    if (new_rules->rules_table[i].required_strings == 0)
+      yr_bitmask_set(new_rules->no_required_strings, i);
+  }
+
   *rules = new_rules;
 
   return ERROR_SUCCESS;
@@ -524,6 +542,7 @@ YR_API int yr_rules_destroy(YR_RULES* rules)
     external++;
   }
 
+  yr_free(rules->no_required_strings);
   yr_arena_release(rules->arena);
   yr_free(rules);
 
