@@ -1,34 +1,41 @@
 #include <yara.h>
-#include "util.h"
+
 #include "blob.h"
+#include "util.h"
 
 int main(int argc, char** argv)
 {
+  int result = 0;
+
+  YR_DEBUG_INITIALIZE();
+  YR_DEBUG_FPRINTF(1, stderr, "+ %s() { // in %s\n", __FUNCTION__, argv[0]);
+
+  init_top_srcdir();
+
   yr_initialize();
 
   assert_true_rule_blob(
-      "import \"elf\" rule test { condition: elf.type }",
-      ELF32_FILE);
+      "import \"elf\" rule test { condition: elf.type }", ELF32_FILE);
 
   assert_true_rule_blob(
-      "import \"elf\" rule test { condition: elf.type }",
-      ELF64_FILE);
+      "import \"elf\" rule test { condition: elf.type }", ELF64_FILE);
 
   assert_true_rule_blob(
       "import \"elf\" rule test { condition: elf.machine == elf.EM_386 }",
       ELF32_FILE)
 
-  assert_true_rule_blob(
-      "import \"elf\" rule test { condition: elf.machine == elf.EM_X86_64 }",
-      ELF64_FILE)
+      assert_true_rule_blob(
+          "import \"elf\" rule test { condition: elf.machine == elf.EM_X86_64 "
+          "}",
+          ELF64_FILE)
 
-  assert_true_rule_blob(
-      "import \"elf\" \
+          assert_true_rule_blob(
+              "import \"elf\" \
       rule test { \
         strings: $a = { b8 01 00 00 00 bb 2a } \
         condition: $a at elf.entry_point \
       }",
-      ELF32_FILE);
+              ELF32_FILE);
 
   assert_true_rule_blob(
       "import \"elf\" \
@@ -122,6 +129,29 @@ int main(int argc, char** argv)
       }",
       ELF32_MIPS_FILE);
 
+  assert_true_rule_blob(
+      "import \"elf\" \
+      rule test { \
+        condition: \
+          for any i in (0..elf.dynsym_entries): ( \
+            elf.dynsym[i].shndx == 11 and \
+            elf.dynsym[i].value == 0x400910 and \
+            elf.dynsym[i].name == \"_fini\") \
+      }",
+      ELF32_MIPS_FILE);
+
+  assert_true_rule_blob(
+      "import \"elf\" \
+      rule test { \
+        condition: \
+          elf.dynsym[9].name == \"__RLD_MAP\" and \
+          elf.dynsym[9].type == elf.STT_OBJECT and \
+          elf.dynsym[9].bind == elf.STB_GLOBAL and \
+          elf.dynsym[9].value == 0x411000 and \
+          elf.dynsym[9].size == 0 \
+      }",
+      ELF32_MIPS_FILE);
+
   assert_true_rule_blob(
       "import \"elf\" \
       rule test { \
@@ -197,7 +227,7 @@ int main(int argc, char** argv)
             elf.symtab[i].value == 0x400400 and \
             elf.symtab[i].name == \"main\") \
      }",
-     ELF_x64_FILE);
+      ELF_x64_FILE);
 
   assert_true_rule_blob(
       "import \"elf\" \
@@ -218,7 +248,7 @@ int main(int argc, char** argv)
           elf.dynamic[13].type == elf.DT_PLTGOT and \
           elf.dynamic[13].val == 0x601000 \
      }",
-     ELF_x64_FILE);
+      ELF_x64_FILE);
 
   assert_true_rule_blob(
       "import \"elf\" \
@@ -230,6 +260,20 @@ int main(int argc, char** argv)
       }",
       ELF_x64_FILE);
 
+  assert_true_rule_file(
+      "import \"elf\" \
+      rule test { \
+        condition: \
+          elf.telfhash() == \
+            \"T174B012188204F00184540770331E0B111373086019509C464D0ACE88181266C09774FA\" \
+      }",
+      "tests/data/elf_with_imports");
+
+
   yr_finalize();
-  return 0;
+
+  YR_DEBUG_FPRINTF(
+      1, stderr, "} = %d // %s() in %s\n", result, __FUNCTION__, argv[0]);
+
+  return result;
 }
